pub enum KeyRotationMethod {
Password {
password: String,
},
KeyConnector,
Tde,
}Variants
Password
Master password user, key rotation without a password change.
KeyConnector
Key connector user, key rotation without a password change. NOTE: This is not yet implemented and will return a RotateUserKeysError::UnimplementedKeyRotationMethod error if used.
Tde
TDE user, key rotation without a password change. NOTE: This is not yet implemented and will return a RotateUserKeysError::UnimplementedKeyRotationMethod error if used.