struct StateUpdate {
user_key: SymmetricCryptoKey,
account_cryptographic_state: WrappedAccountCryptographicState,
upgrade_token: Option<V2UpgradeToken>,
}Expand description
Data that needs to be written to local state after the key rotation was successfully posted to the server
Fields
user_key: SymmetricCryptoKeyaccount_cryptographic_state: WrappedAccountCryptographicStateupgrade_token: Option<V2UpgradeToken>Auto Trait Implementations
impl Freeze for StateUpdate
impl RefUnwindSafe for StateUpdate
impl Send for StateUpdate
impl Sync for StateUpdate
impl Unpin for StateUpdate
impl UnsafeUnpin for StateUpdate
impl UnwindSafe for StateUpdate